@@ -22,6 +22,9 @@ from shioaji.constant import (
 )
 
 
+logger.add("sjtrader.log", rotation="1 days")
+
+
 class SJTrader:
     def __init__(self, api: sj.Shioaji, simulation: bool = False):
         self.api = api
@@ -131,7 +134,7 @@ class SJTrader:
         if not contract:
             logger.warning(f"Code: {code} not exist in TW Stock.")
         else:
-            self.positions[code] = Position(
+            position = self.positions[code] = Position(
                 contract=contract,
                 cond=PositionCond(
                     quantity=pos,
@@ -143,10 +146,12 @@ class SJTrader:
             )
             self.snapshots[code] = Snapshot(price=0.0)
             self.api.quote.subscribe(contract, version=QuoteVersion.v1)
-            for price_set in self.positions[code].cond.entry_price:
+            for price_set in position.cond.entry_price:
+                if abs(price_set.quantity) == abs(price_set.in_transit_quantity):
+                    continue
                 price, price_quantity = price_set.price, price_set.quantity
                 quantity_s = quantity_split(price_quantity, threshold=499)
-                with self.positions[code].lock:
+                with position.lock:
                     for q in quantity_s:
                         trade = api.place_order(
                             contract=contract,
@@ -163,7 +168,9 @@ class SJTrader:
                             ),
                             timeout=0,
                         )
-                        self.positions[code].entry_trades.append(trade)
+                        price_set.in_transit_quantity += q
+                        # position.status.entry_order_in_transit += q
+                        position.entry_trades.append(trade)
                         logger.info(f"{code} | {trade.order}")
 
     def place_entry_positions(self) -> Dict[str, Position]:
@@ -184,13 +191,14 @@ class SJTrader:
             api = self.api
         # 8:55 - 8:59:55
         if tick.simtrade:
-            if position.cond.quantity < 0 and tick.close == position.contract.limit_up:
+            if position.cond.quantity < 0 and float(tick.close) == position.contract.limit_up:
                 with position.lock:
                     position.status.cancel_preorder = True
                 for trade in self.positions[tick.code].entry_trades:
                     if trade.status.status != sj.order.Status.Cancelled:
-                        api.cancel_order(trade, timeout=0)
+                        api.cancel_order(trade)
                         logger.info(f"{trade.contract.code} | {trade.order}")
+                        api.update_status(trade=trade)
                         # check handle
                         # self.update_status(trade)
                         # if trade.status.status == sj.order.Status.Cancelled:
@@ -210,7 +218,7 @@ class SJTrader:
                 self.open_price[tick.code] = tick.close
                 if (
                     position.status.cancel_preorder
-                    and tick.close < position.cond.stop_loss_price[0].price
+                    and float(tick.close) < position.cond.stop_loss_price[0].price
                 ):  # TODO check min or max
                     trade = api.place_order(
                         contract=position.contract,
@@ -256,7 +264,9 @@ class SJTrader:
                 op = operator.le
                 cross = "under"
             for price_set in position.cond.stop_profit_price:
-                if op(tick.close, price_set.price):
+                if op(float(tick.close), price_set.price):
+                    if abs(price_set.quantity) == abs(price_set.in_transit_quantity):
+                        continue
                     self.place_cover_order(position, [price_set])
                     logger.info(
                         f"{position.contract.code} | price: {tick.close} cross {cross} {price_set.price} "
@@ -277,7 +287,9 @@ class SJTrader:
                 op = operator.ge
                 cross = "over"
             for price_set in position.cond.stop_loss_price:
-                if op(tick.close, price_set.price):
+                if op(float(tick.close), price_set.price):
+                    if abs(price_set.quantity) == abs(price_set.in_transit_quantity):
+                        continue
                     self.place_cover_order(position, [price_set])
                     logger.info(
                         f"{position.contract.code} | price: {tick.close} cross {cross} {price_set.price} "
@@ -298,9 +310,12 @@ class SJTrader:
             price_sets = self.stratagy.cover_price_set(
                 position, self.snapshots[position.contract.code]
             )
+            position.cond.cover_price += price_sets
         if cover_quantity == 0:
             return
         for price_set in price_sets:
+            if abs(price_set.quantity) == abs(price_set.in_transit_quantity):
+                continue
             if price_set.quantity:
                 quantity_s = quantity_split(price_set.quantity, threshold=499)
                 for q in quantity_s:
@@ -319,8 +334,9 @@ class SJTrader:
                         timeout=0,
                     )
                     logger.info(f"{trade.contract.code} | {trade.order}")
+                    price_set.in_transit_quantity += q
                     position.cover_trades.append(trade)
-                    api.update_status(trade=trade)
+                    # api.update_status(trade=trade)
 
     def open_position_cover(self, onclose: bool = True):
         if self.simulation:
